aboutsummaryrefslogtreecommitdiff
path: root/middleware/ignismiddleware.py
diff options
context:
space:
mode:
Diffstat (limited to 'middleware/ignismiddleware.py')
-rw-r--r--middleware/ignismiddleware.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/middleware/ignismiddleware.py b/middleware/ignismiddleware.py
index 2b51a740..85c2c0e2 100644
--- a/middleware/ignismiddleware.py
+++ b/middleware/ignismiddleware.py
@@ -25,8 +25,8 @@ class IgnisMiddleware(MiddlewareMixin):
def __call__(self, request):
response = self.get_response(request)
- # id request is from localhost, do not process
- if re.match(r"^localhost", request.get_host()):
+ # id request is from localhost or 127.0.0.1, do not process
+ if re.match(r"^localhost", request.get_host()) or re.match(r"^127.0.0.1", request.get_host()):
return response
# Do not process non-HTML responses